@@ -219,6 +219,7 @@ CREATE TABLE ofMucRoom (
   useReservedNick     INTEGER       NOT NULL,
   canChangeNick       INTEGER       NOT NULL,
   canRegister         INTEGER       NOT NULL,
+  allowpm             INTEGER       NULL,
   CONSTRAINT ofMucRoom_pk PRIMARY KEY (serviceID, name)
 );
 CREATE INDEX ofMucRoom_roomid_idx ON ofMucRoom (roomID);
@@ -252,13 +253,16 @@ CREATE TABLE ofMucMember (
 
 CREATE TABLE ofMucConversationLog (
   roomID              BIGINT        NOT NULL,
+  messageID         BIGINT      NOT NULL,
   sender              VARCHAR(1024) NOT NULL,
   nickname            VARCHAR(255)  NULL,
   logTime             CHAR(15)      NOT NULL,
   subject             VARCHAR(255)  NULL,
-  body                LONGVARCHAR   NULL
+  body                LONGVARCHAR   NULL,
+  stanza             LONGVARCHAR    NULL
 );
 CREATE INDEX ofMucConversationLog_time_idx ON ofMucConversationLog (logTime);
+CREATE INDEX ofMucConversationLog_msg_id ON ofMucConversationLog (messageID);
 
 // PubSub Tables
 
@@ -376,7 +380,7 @@ INSERT INTO ofID (idType, id) VALUES (19, 1);
 INSERT INTO ofID (idType, id) VALUES (23, 1);
 INSERT INTO ofID (idType, id) VALUES (26, 2);
 
-INSERT INTO ofVersion (name, version) VALUES ('openfire', 22);
+INSERT INTO ofVersion (name, version) VALUES ('openfire', 25);
 
 // Entry for admin user
 INSERT INTO ofUser (username, plainPassword, name, email, creationDate, modificationDate)
@@ -388,8 +392,8 @@ INSERT INTO ofMucService (serviceID, subdomain, isHidden) VALUES (1, 'conference
 // The value is the size in megabytes that the .log file can reach before an automatic
 // checkpoint occurs. A checkpoint rewrites the .script file and clears the .log file
 // see http://www.hsqldb.org/doc/guide/ch04.html#hsqldb.log_size
-SET LOGSIZE 20
+SET FILES LOG SIZE 20;
 
 // This controls the frequency of file sync for the log file.
 // see http://www.hsqldb.org/doc/guide/ch09.html#set_write_delay-section
-SET WRITE_DELAY 1000 MILLIS;
\ No newline at end of file
+SET FILES WRITE DELAY 1000 MILLIS;
