@@ -222,6 +222,7 @@ CREATE TABLE ofMucRoom (
   useReservedNick     INT           NOT NULL,
   canChangeNick       INT           NOT NULL,
   canRegister         INT           NOT NULL,
+  allowpm             INT           NULL,
   CONSTRAINT ofMucRoom_pk PRIMARY KEY (serviceID, name)
 );
 CREATE INDEX ofMucRoom_roomid_idx on ofMucRoom(roomID);
@@ -255,13 +256,17 @@ CREATE TABLE ofMucMember (
 
 CREATE TABLE ofMucConversationLog (
   roomID              INT            NOT NULL,
+  messageID              INT            NOT NULL,
   sender              TEXT           NOT NULL,
   nickname            NVARCHAR(255)  NULL,
   logTime             CHAR(15)       NOT NULL,
   subject             NVARCHAR(255)  NULL,
-  body                TEXT           NULL
+  body                TEXT           NULL,
+  stanza                TEXT           NULL
 );
 CREATE INDEX ofMucConversationLog_time_idx ON ofMucConversationLog (logTime);
+CREATE INDEX ofMucConversationLog_msg_id ON ofMucConversationLog (messageID);
+
 
 /* PubSub Tables */
 
@@ -379,7 +384,7 @@ INSERT INTO ofID (idType, id) VALUES (19, 1);
 INSERT INTO ofID (idType, id) VALUES (23, 1);
 INSERT INTO ofID (idType, id) VALUES (26, 2);
 
-INSERT INTO ofVersion (name, version) VALUES ('openfire', 22);
+INSERT INTO ofVersion (name, version) VALUES ('openfire', 25);
 
 /* Entry for admin user */
 INSERT INTO ofUser (username, plainPassword, name, email, creationDate, modificationDate)
